# procs
⊕ [abseil-py/sample_app.py at master · abseil/abseil-py](https://github.com/abseil/abseil-py/blob/master/smoke_tests/sample_app.py)

```sh
$ python sample_app.py --echo hel
Running under Python 3.6.4
I0101 16:03:06.654367 140736134763392 sample_app.py:37] echo is hel.
```

